@@ -113,6 +113,10 @@ def get_dates_for_course(course_id, user=None, use_cached=True, schedule=None):
     dates = {}
     policies = {}
     need_schedule = schedule is None and user is not None
+    end_content_date = list(filter(lambda cd: cd.location.block_type == 'course' and cd.field == 'end', qset))
+    end_datetime = None
+    if end_content_date:
+        end_datetime = end_content_date[0].policy.abs_date
     for cdate in qset:
         if need_schedule:
             need_schedule = False
@@ -120,7 +124,7 @@ def get_dates_for_course(course_id, user=None, use_cached=True, schedule=None):
 
         key = (cdate.location, cdate.field)
         try:
-            dates[key] = cdate.policy.actual_date(schedule)
+            dates[key] = cdate.policy.actual_date(schedule, end_datetime)
         except ValueError:
             log.warning("Unable to read date for %s", cdate.location, exc_info=True)
         policies[cdate.id] = key
